@@ -2,32 +2,8 @@
  * Like what you see? Join us!
  * https://www.univention.com/about-us/careers/vacancies/
  *
- * Copyright 2011-2025 Univention GmbH
- *
- * https://www.univention.de/
- *
- * All rights reserved.
- *
- * The source code of this program is made available
- * under the terms of the GNU Affero General Public License version 3
- * (GNU AGPL V3) as published by the Free Software Foundation.
- *
- * Binary versions of this program provided by Univention to you as
- * well as other copyrighted, protected or trademarked materials like
- * Logos, graphics, fonts, specific documentations and configurations,
- * cryptographic keys etc. are subject to a license agreement between
- * you and Univention and not subject to the GNU AGPL V3.
- *
- * In the case you use this program under the terms of the GNU AGPL V3,
- * the program is provided in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public
- * License with the Debian GNU/Linux or Univention distribution in file
- * /usr/share/common-licenses/AGPL-3; if not, see
- * <https://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2011-2025 Univention GmbH
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
 /*global define, require, console, window*/
 
@@ -921,6 +897,10 @@ define([
 			var _isAdvancedSearch = this._ucr['directory/manager/web/modules/' + this.moduleFlavor + '/search/advanced_on_open'] ||
 				this._ucr['directory/manager/web/modules/search/advanced_on_open'];
 			this._isAdvancedSearch = tools.isTrue(_isAdvancedSearch);
+			var _globalSearch = this._ucr['directory/manager/web/modules/' + this.moduleFlavor + '/search/global-search'] || this._ucr['directory/manager/web/modules/search/global-search'] || 'true';
+			this._globalSearch = tools.isTrue(_globalSearch);
+			var _defaultSearch = this._ucr['directory/manager/web/modules/' + this.moduleFlavor + '/search/default-search'] || this._ucr['directory/manager/web/modules/search/default-search'] || 'false';
+			this._defaultSearch = tools.isTrue(_defaultSearch)
 
 			var umcpCmd = lang.hitch(this, 'umcpCommand');
 			var widgets = [];
@@ -950,7 +930,12 @@ define([
 				objTypes.push({ id: this.moduleFlavor, label: _('All types') });
 			} else if (containers && containers.length) {
 				// containers...
-				containers.unshift({ id: 'all', label: _('All containers') });
+				if (this._globalSearch) {
+					containers.unshift({ id: 'all', label: _('All containers') });
+				}
+				if (this._defaultSearch) {
+					containers.unshift({ id: 'default', label: _('Default containers') })
+				}
 				widgets.push({
 					type: ComboBox,
 					name: 'container',
